@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2017 Robert & Jeremy Laine
+ * Copyright (C) Robert Lainé & Jeremy Lainé
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -194,7 +194,7 @@ void CBoatElementWidget::slotReload()
         }
         signalUpdate(element);
     }
-    catch (read_error e)
+    catch (read_error const&)
     {
         CSailDefXmlWriter::readErrorMessage();
     }
