@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2017 Robert & Jeremy Laine
+ * Copyright (C) Robert Lainé & Jeremy Lainé
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,35 +20,28 @@
 #ifndef FILEWRITER_H
 #define FILEWRITER_H
 
-#ifdef WIN32
-#define CRLF   endl
-#else
-#define CRLF "\r\n"
-#endif
-
 #include <iostream>
 #include <stdexcept>
 
 #include <QFileDialog>
 #include <QMessageBox>
 
-using namespace std;
 
-class read_error : public runtime_error
+class read_error : public std::runtime_error
 {
 public:
-    read_error(const string &message) : runtime_error(message)
+    read_error(const std::string &message) : std::runtime_error(message)
     {
-        cout << what() << endl;
+        std::cout << what() << std::endl;
     }
 };
 
-class write_error : public runtime_error
+class write_error : public std::runtime_error
 {
 public:
-    write_error(const string &message) : runtime_error(message)
+    write_error(const std::string &message) : std::runtime_error(message)
     {
-        cout << what() << endl;
+        std::cout << what() << std::endl;
     }
 };
 
@@ -94,7 +87,7 @@ public:
      */
     virtual const objtype read(const QString &) const
     {
-        throw logic_error("Reading is not supported for this file type.");
+        throw std::logic_error("Reading is not supported for this file type.");
     };
 
 
@@ -103,15 +96,15 @@ public:
      * @param dest the object we read to
      * @param filename initial file name
      */
-    QString readDialog(objtype &dest, const QString &filename = "") const
+    QString readDialog(objtype &dest, const QString &filename = QString()) const
     {
         const QString newfilename = getOpenFileName(filename);
         if (!newfilename.isNull()) {
             try {
                 dest = read(newfilename);
-            } catch (read_error e) {
+            } catch (read_error const&) {
                 readErrorMessage();
-                return QString::null;
+                return QString();
             }
         }
         return newfilename;
@@ -137,15 +130,15 @@ public:
      *  @param obj The object to write.
      *  @param filename The filename to start off with (default = "")
      */
-    QString writeDialog(const objtype &obj, const QString &filename = QString::null) const
+    QString writeDialog(const objtype &obj, const QString &filename = QString()) const
     {
         const QString newfilename = getSaveFileName(filename);
         if (!newfilename.isNull()) {
             try {
                 write(obj, newfilename);
-            } catch (write_error e) {
+            } catch (write_error const&) {
                 writeErrorMessage();
-                return QString::null;
+                return QString();
             }
         }
         return newfilename;
