@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2017 Robert & Jeremy Laine
+ * Copyright (C) Robert Lainé & Jeremy Lainé
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -88,7 +88,7 @@ void CFormBoat::add(const QString &newfile)
     }
     else
     {
-        throw invalid_argument("CFormBoat::add : unknown document type");
+        throw std::invalid_argument("CFormBoat::add : unknown document type");
     }
     element.filename = newfile.toStdString();
     def.push_back(element);
@@ -113,7 +113,7 @@ bool CFormBoat::read(const QString &filename)
     try {
         setDef(writer.read(filename));
         return true;
-    } catch (read_error e) {
+    } catch (read_error const&) {
         return false;
     }
 }
@@ -124,7 +124,7 @@ bool CFormBoat::write(const QString &filename)
     try {
         writer.write(def, filename);
         return true;
-    } catch (write_error e) {
+    } catch (write_error const&) {
         return false;
     }
 }
