@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2017 Robert & Jeremy Laine
+ * Copyright (C) Robert Lainé & Jeremy Lainé
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -17,6 +17,10 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#include <QMenuBar>
+#include <QMessageBox>
+#include <QStatusBar>
+
 #include "app.h"
 #include "formmain.h"
 #include "formsail.h"
@@ -27,9 +31,6 @@
 
 #include "sailcut.xpm"
 
-#include <QMenuBar>
-#include <QStatusBar>
-
 
 /**
  * Constructs Sailcut CAD's main window.
@@ -204,11 +205,11 @@ void CFormMain::slotAbout()
 
                         "<h2>Sailcut CAD " SAILCUT_VERSION "</h2>"
                         "<p>Sailcut is a software for designing boat sails<br/>"
-                        "(C) 1993-2017 Robert & Jeremy Laine"
+                        "Copyright (C) Robert Lainé & Jeremy Lainé"
 
                         "<p>For more information, visit the project's page at <a href=\"http://www.sailcut.com/\">http://www.sailcut.com/</a>.</p>"
 
-                        "<p>Sailcut is a trademark registered by Robert Laine</p>"
+                        "<p>Sailcut is a trademark registered by Robert Lainé</p>"
 
                         "<table border=\"1\"><tr><td><small>"
                         "This program is free software; you can redistribute it and/or modify "
