@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2017 Robert & Jeremy Laine
+ * Copyright (C) Robert Lainé & Jeremy Lainé
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,15 +21,14 @@
 #include "sailpainter.h"
 #include "sailprinter.h"
 
-#include <QDebug>
 #include <QBoxLayout>
+#include <QDebug>
 #include <QDoubleSpinBox>
-#include <QPushButton>
-#include <QToolButton>
 #include <QPageSetupDialog>
 #include <QPrintDialog>
-#include <QMessageBox>
+#include <QPushButton>
 #include <QResizeEvent>
+#include <QToolButton>
 
 
 /** Construct a new print preview label.
@@ -40,13 +39,11 @@ CPrintLabel::CPrintLabel(CFormPrint *frm)
         : form(frm), resizing(false)
 {
     QPalette pal = palette();
-    pal.setColor( QPalette::Background, Qt::white );
+    pal.setColor( QPalette::Window, Qt::white );
     setPalette( pal );
 
     // set the initial size
-    QRect print = form->printDevice.pageRect();
-    real rprint = real(print.width()) / real(print.height());
-    if (rprint > 1)
+    if (form->printDevice.pageLayout().orientation() == QPageLayout::Landscape)
     {
         setMinimumSize( QSize( 375, 250 ) );
     }
@@ -61,8 +58,6 @@ CPrintLabel::CPrintLabel(CFormPrint *frm)
  */
 void CPrintLabel::paintEvent(QPaintEvent *)
 {
-    form->printDevice.pageRect();
-
     // erase viewport
     CTextPainter painter(this);
     QRect rect = painter.viewport();
@@ -78,7 +73,7 @@ void CPrintLabel::paintEvent(QPaintEvent *)
  */
 void CPrintLabel::resizeEvent (QResizeEvent *)
 {
-    QRect print = form->printDevice.pageRect();
+    QRectF print = form->printDevice.pageRect(QPrinter::Millimeter);
     if (resizing || !print.width() || !print.height() || !widthMM() || !heightMM())
         return;
 
@@ -143,11 +138,11 @@ void CPrintLabel::slotScale(double value)
  * @param engine
  * @param orientation
  */
-CFormPrint::CFormPrint(const CPrinter *engine, enum QPrinter::Orientation orientation)
+CFormPrint::CFormPrint(const CPrinter *engine, QPageLayout::Orientation orientation)
         : printEngine(engine), printFontSize(10)
 {
     // initialise printer
-    printDevice.setOrientation(orientation);
+    printDevice.setPageOrientation(orientation);
     printDevice.setFullPage(false);
 
     QVBoxLayout *layout = new QVBoxLayout(this);
