@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2017 Robert & Jeremy Laine
+ * Copyright (C) Robert Lainé & Jeremy Lainé
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -22,6 +22,7 @@
 
 #include <QDialog>
 #include <QLabel>
+#include <QPageLayout>
 #include <QPrinter>
 
 class CFormPrint;
@@ -75,7 +76,7 @@ class CFormPrint : public QDialog
     Q_OBJECT
 
 public:
-    CFormPrint(const CPrinter *printer, enum QPrinter::Orientation orientation);
+    CFormPrint(const CPrinter *printer, QPageLayout::Orientation orientation);
 
 public slots:
     void slotPrint();
