@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2017 Robert & Jeremy Laine
+ * Copyright (C) Robert Lainé & Jeremy Lainé
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -109,7 +109,7 @@ bool CFormSail::read(const QString &filename)
     try {
         setDef(writer.read(filename));
         return true;
-    } catch (read_error e) {
+    } catch (read_error const&) {
         return false;
     }
 }
@@ -120,7 +120,7 @@ bool CFormSail::write(const QString &filename)
     try {
         writer.write(def, filename);
         return true;
-    } catch (write_error e) {
+    } catch (write_error const&) {
         return false;
     }
 }
@@ -360,7 +360,7 @@ void CFormSail::slotMould()
 void CFormSail::slotPrintData()
 {
     CSailDataPrinter prt(def);
-    CFormPrint(&prt, QPrinter::Portrait).exec();
+    CFormPrint(&prt, QPageLayout::Portrait).exec();
 }
 
 
@@ -371,7 +371,7 @@ void CFormSail::slotPrintData()
 void CFormSail::slotPrintDev()
 {
     CSailDevelPrinter prt(flatsail);
-    CFormPrint(&prt, QPrinter::Landscape).exec();
+    CFormPrint(&prt, QPageLayout::Landscape).exec();
 }
 
 
@@ -381,7 +381,7 @@ void CFormSail::slotPrintDev()
 void CFormSail::slotPrintDwg()
 {
     CSailDrawingPrinter prt(sail);
-    CFormPrint(&prt, QPrinter::Portrait).exec();
+    CFormPrint(&prt, QPageLayout::Portrait).exec();
 }
 
 
