@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2017 Robert & Jeremy Laine
+ * Copyright (C) Robert Lainé & Jeremy Lainé
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,6 +19,7 @@
 
 #include <cmath>
 
+#include <QButtonGroup>
 #include <QLabel>
 #include <QMessageBox>
 #include <QRadioButton>
@@ -219,7 +220,7 @@ void CFormSailDef::setSailType( enumSailType type )
     {
     case MAINSAIL:
 #ifdef DEBUG
-        cout << "setSailType( MAINSAIL )" << endl;
+        std::cout << "setSailType( MAINSAIL )" << std::endl;
 #endif
         radioMainSail->setChecked( true );
         txtTackDist->setEnabled( true );
@@ -245,7 +246,7 @@ void CFormSailDef::setSailType( enumSailType type )
 
     case JIB:
 #ifdef DEBUG
-        cout << "setSailType( JIB )" << endl;
+        std::cout << "setSailType( JIB )" << std::endl;
 #endif
         radioJib->setChecked( true );
         txtTackDist->setEnabled( false );
@@ -271,7 +272,7 @@ void CFormSailDef::setSailType( enumSailType type )
 
     case WING:
 #ifdef DEBUG
-        cout << "setSailType( WING )" << endl;
+        std::cout << "setSailType( WING )" << std::endl;
 #endif
         radioWing->setChecked( true );
         txtTackDist->setEnabled( true );
@@ -1063,29 +1064,11 @@ bool CFormSailDef::check()
         txtSheetAngle->setPalette( palHi);
         saildef->sheetDeg = 45;
     }
-    else
-    {
-        txtSheetAngle->setPalette( palStd);
-    }
-
-    switch (saildef->sailType ) // set lower limit for sheeting main or jib
-    {
-    case MAINSAIL:
-        L2 = 0;
-        break;
-    case JIB:
-        L2 = 5;
-        break;
-    case WING:
-        L2 = 0;
-        break;
-    }
-
-    if (saildef->sheetDeg < L2)
+    else if (saildef->sheetDeg < 0)
     {
         flag=false;
         txtSheetAngle->setPalette( palLo);
-        saildef->sheetDeg = L2;
+        saildef->sheetDeg = 0;
     }
     else
     {
@@ -1227,22 +1210,8 @@ void CFormSailDef::slotCompute()
     w1 = worker.SailWidth(h);
     txtc = txtc  + "\n  h= "+QString::number(h)+"\t IRC w= "+QString::number(int(w)) +" mm \t IOR w= " +QString::number(int(w1)) +" mm";
 
-    displayData(  txta, txtb, txtc, txtd, txte );
-}
-
-
-/**
- *  Display ancillary data in a message box
- */
-void CFormSailDef::displayData(QString &txt0, QString &txt1, QString &txt2, QString &txt3, QString &txt4 )
-{
-    QMessageBox* mb = new QMessageBox();
-    mb->setIcon(QMessageBox::NoIcon);
-    mb->setWindowTitle("Sailcut");
-    mb->setText (QString(txt0+"\n" +txt1+"\n" +txt2+"\n" +txt3+"\n" +txt4));
-    mb->setButtonText (0, "OK");
-    mb->exec();
-    delete mb;
+    // Display ancillary data in a message box.
+    QMessageBox::information(this, "Sailcut", txta + "\n" + txtb + "\n" + txtc + "\n" + txtd + "\n" + txte);
 }
 
 
