@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2017 Robert & Jeremy Laine
+ * Copyright (C) Robert Lainé & Jeremy Lainé
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -88,15 +88,6 @@ CSubSpace::CSubSpace(const CVector3d &pi, const CMatrix &mi, subspaceflags_t cre
 }
 
 
-/** Copy constructor */
-CSubSpace::CSubSpace(const CSubSpace &s)
-    : isEmpty(s.isEmpty)
-    , m(s.m)
-    , p(s.p)
-{
-}
-
-
 /** Test whether the CSubSpace contains a given point.
  */
 bool CSubSpace::contains(const CVector3d &point) const
@@ -144,8 +135,6 @@ CSubSpace CSubSpace::intersect(const CSubSpace &h2) const
             bb[i] = b2[i - m.rows()];
         }
     }
-    //cout << "mm" << endl << mm << endl;
-    //cout << "bb" << endl << bb << endl;
 
     soltype_t soltype = NONE;
     CMatrix k;
@@ -156,13 +145,13 @@ CSubSpace CSubSpace::intersect(const CSubSpace &h2) const
     switch (soltype)
     {
     case ONE:
-        //cout << "CMatrix::solve : system has unique solution" << endl;
+        // system has unique solution
         return CSubSpace(s, CMatrix::id(SIZE), GEOCPP_FROM_EQS);
     case INF:
-        //cout << "CMatrix::solve : system has an infinity of solutions" << endl;
+        // system has an infinity of solutions
         return CSubSpace(s, k, GEOCPP_FROM_BASE);
     case NONE:
-        //cout << "CMatrix::solve : system has no solution" << endl;
+        // system has no solution
         break;
     }
     return CSubSpace();
@@ -236,7 +225,7 @@ ostream& operator<< (ostream &o, const CMatrix &m)
     {
         o << m.row(i);
         if ( i != m.rows() - 1 )
-            o << endl;
+            o << std::endl;
     }
     o << "]";
     return o;
@@ -247,36 +236,36 @@ ostream& operator<< (ostream &o, const CMatrix &m)
  */
 ostream& operator<< (ostream &o, const CSubSpace &h)
 {
-    o << "--------------------------------" << endl;
+    o << "--------------------------------" << std::endl;
     o << "     subspace : ";
     switch (h.getdim())
     {
     case -1:
-        o << "empty" << endl;
+        o << "empty" << std::endl;
         break;
     case 0:
-        o << "point" << endl;
+        o << "point" << std::endl;
         break;
     case 1:
-        o << "line" << endl;
+        o << "line" << std::endl;
         break;
     case 2:
-        o << "plane" << endl;
+        o << "plane" << std::endl;
         break;
     default:
-        o << "dim=" << h.getdim() << endl;
+        o << "dim=" << h.getdim() << std::endl;
     }
-    o << "--------------------------------" << endl;
+    o << "--------------------------------" << std::endl;
     if ( h.getdim() >= 0 )
     {
-        o << "point:" << endl << h.getp() << endl;
+        o << "point:" << std::endl << h.getp() << std::endl;
         if (h.getdim()>0)
         {
-            o << "------" << endl;
-            o << "base vectors (in columns): " << endl << h.getm().kern(h.getp().size()) << endl << "------" << endl;
-            o << "equations (coeffs in lines): " << endl << h.getm() << endl;
+            o << "------" << std::endl;
+            o << "base vectors (in columns): " << std::endl << h.getm().kern(h.getp().size()) << std::endl << "------" << std::endl;
+            o << "equations (coeffs in lines): " << std::endl << h.getm() << std::endl;
         }
-        o << "--------------------------------" << endl;
+        o << "--------------------------------" << std::endl;
     }
     return o;
 }
