@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2017 Robert & Jeremy Laine
+ * Copyright (C) Robert Lainé & Jeremy Lainé
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -23,8 +23,6 @@
 #include <vector>
 #include <QString>
 
-using namespace std;
-
 /**
  * A class used to store a user's preferences.
  */
@@ -34,7 +32,7 @@ public:
     CPrefs();
 
     /** The most recently used documents. */
-    vector<QString> mruDocuments;
+    std::vector<QString> mruDocuments;
 
     /** The width of the main window */
     int mainWindowWidth;
