@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2017 Robert & Jeremy Laine
+ * Copyright (C) Robert Lainé & Jeremy Lainé
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -37,7 +37,7 @@ public:
     /** the type of file this element was read from (sail, hull definition or 3D panels) */
     enumBoatElementType type;
     /** the name of the file this element was read from */
-    string filename;
+    std::string filename;
     /** the origin of the element */
     CPoint3d origin;
 };
@@ -48,7 +48,7 @@ public:
  *
  * @see CBoatElement
  */
-class CBoatDef : public vector<CBoatElement>
+class CBoatDef : public std::vector<CBoatElement>
 {
 public:
     CBoatDef();
