@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2017 Robert & Jeremy Laine
+ * Copyright (C) Robert Lainé & Jeremy Lainé
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -53,50 +53,4 @@ CHullDef::CHullDef()
     AutoPlank = true;
     TopPlankA = 75;   // inclination in degree from horizontal
     LowPlankA = 30;
-
 }
-
-
-/** Assignment operator.
- *
- * @param copy the hull definition to copy from
- * @return CHullDef&
- */
-CHullDef & CHullDef::operator=( const CHullDef &copy )
-{
-    if (&copy == this)
-        return *this;
-    // else new data to be copied
-    hullID = copy.hullID;
-    DLOA = copy.DLOA;
-    DfwdHeight = copy.DfwdHeight;
-    DaftHeight = copy.DaftHeight;
-    DSlopeA = copy.DSlopeA;
-    DBW = copy.DBW;
-    DBWPos = copy.DBWPos;
-    DaftW = copy.DaftW;
-    StemA = copy.StemA;
-    TransomA = copy.TransomA;
-
-    BLWL = copy.BLWL;
-    BfwdHeight = copy.BfwdHeight;
-    BaftHeight = copy.BaftHeight;
-    BSlopeA = copy.BSlopeA;
-    BBW = copy.BBW;
-    BBWPos = copy.BBWPos;
-    BaftW = copy.BaftW;
-
-    BDeadriseA = copy.BDeadriseA;
-    BSweepA = copy.BSweepA;
-    BfwdShape = copy.BfwdShape;
-    BaftShape = copy.BaftShape;
-
-    NBPlank = copy.NBPlank;
-    AutoPlank = copy.AutoPlank;
-    TopPlankA = copy.TopPlankA;
-    LowPlankA = copy.LowPlankA;
-
-    return *this;
-}
-
-
