@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2017 Robert & Jeremy Laine
+ * Copyright (C) Robert Lainé & Jeremy Lainé
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -35,10 +35,8 @@ class CHullDef
 public:
     CHullDef();
 
-    CHullDef & operator=( const CHullDef & );
-
     /** hull ID name */
-    string hullID;
+    std::string hullID;
 
         //deck
     /** deck Length in millimeter */
@@ -93,7 +91,6 @@ public:
     int TopPlankA;
     /** lower plank angle in degree from horizontal */
     int LowPlankA;
-        //
 };
 
 #endif
