@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2017 Robert & Jeremy Laine
+ * Copyright (C) Robert Lainé & Jeremy Lainé
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -28,15 +28,14 @@
 #include <geocpp/geocpp.h>
 
 enum enumPointType { LUFF, FOOT, LEECH, GAFF };
-enum enumAlign {LEFT, LOW_LEFT, BOTTOM};
 enum enumDevelopAlign {ALIGN_TOP,ALIGN_BOTTOM };
 
-class panel_error : public runtime_error
+class panel_error : public std::runtime_error
 {
 public:
-    panel_error(const string &message) : runtime_error(message)
+    panel_error(const std::string &message) : std::runtime_error(message)
     {
-        cout << "in panel: " << what()  << endl;
+        std::cout << "in panel: " << what() << std::endl;
     }
 };
 
@@ -54,7 +53,7 @@ public:
     CPanelLabel( const CPanelLabel& );
 
     /** label name of the panel */
-    string name;
+    std::string name;
 
     /** label text height (default : 5) */
     int height;
@@ -73,7 +72,7 @@ public:
     /** operator to copy a label */
     CPanelLabel& operator=( const CPanelLabel &);
 
-    friend ostream& operator<< (ostream &, const CPanelLabel &);
+    friend std::ostream& operator<< (std::ostream &, const CPanelLabel &);
 };
 
 
@@ -87,7 +86,7 @@ public:
  *
  * @ingroup SailCpp
  */
-class CSide : public vector<CPoint3d>
+class CSide : public std::vector<CPoint3d>
 {
 public:
     CSide( unsigned int = 1 );
@@ -96,10 +95,13 @@ public:
     void fill( const CPoint3d &, const CPoint3d & );
     void fill( const CPoint3d &, const CPoint3d &, const CPoint3d & );
 
+    real bottom() const;
+    real left() const;
+
     CSide transformed(const CMatrix4x4 &m) const;
 
     // operators
-    friend ostream& operator<< (ostream &, const CSide &);
+    friend std::ostream& operator<< (std::ostream &, const CSide &);
 };
 
 
@@ -174,19 +176,19 @@ public:
     CPanel develop(enumDevelopAlign align) const;
 
     void placeLabel();   //  place a label at the center of a panel
-    CPanel reframe(enumAlign align) const;
+    void reframe();
     CPanel rotated(const CPoint3d &, real angle, Qt::Axis axis) const;
     CPanel transformed(const CMatrix4x4 &m) const;
     CPanel operator+ (const CVector3d &) const;
     CPanel& operator= (const CPanel &);
 
-    friend ostream& operator<< (ostream &, const CPanel &);
+    friend std::ostream& operator<< (std::ostream &, const CPanel &);
 };
 
 // global functions
-ostream& operator<< (ostream &, const CPanel &);
-ostream& operator<< (ostream &, const CSide &);
-ostream& operator<< (ostream &, const CPanelLabel &);
+std::ostream& operator<< (std::ostream &, const CPanel &);
+std::ostream& operator<< (std::ostream &, const CSide &);
+std::ostream& operator<< (std::ostream &, const CPanelLabel &);
 
 CVector3d rotateNormalized(real angle, const CVector3d &v);
 
