@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2017 Robert & Jeremy Laine
+ * Copyright (C) Robert Lainé & Jeremy Lainé
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -17,8 +17,6 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include <cstdio>
-
 #include "panelgroup.h"
 
 /** Constructs a panel group with the specified number of panels.
@@ -33,7 +31,7 @@ CPanelGroup::CPanelGroup( unsigned int nbpanels /* = 0 */)
 /** Copy constructor.
  */
 CPanelGroup::CPanelGroup( const CPanelGroup& s )
-        : vector<CPanel>(s)
+        : std::vector<CPanel>(s)
 {
     title = s.title;
     child = s.child;
@@ -87,9 +85,7 @@ void CPanelGroup::placeLabels()
 {
     for (unsigned int i = 0; i < size(); i++)
     {
-        char buffer[32];
-        sprintf(buffer, "%i", i);
-        at(i).label.name = buffer;
+        at(i).label.name = std::to_string(i);
         at(i).placeLabel();
     }
 }
@@ -102,10 +98,7 @@ void CPanelGroup::plotLabels()
 {
     for (unsigned int i = 0; i < size(); i++)
     {
-        char buffer[32];
-        sprintf(buffer, "%i", i);
-        at(i).label.name = buffer;
-
+        at(i).label.name = std::to_string(i);
         at(i).label.height = 5;
         // position the label and orientate it
         at(i).label.origin = at(i).bottom[2];
@@ -135,7 +128,7 @@ CPanelGroup& CPanelGroup::operator=(const CPanelGroup& s)
     if (&s == this)
         return *this;
 
-    this->vector<CPanel>::operator=(s);
+    this->std::vector<CPanel>::operator=(s);
     title = s.title;
     child = s.child;
     type = s.type;
@@ -146,18 +139,18 @@ CPanelGroup& CPanelGroup::operator=(const CPanelGroup& s)
 
 /** Outputs a CPanelGroup to a stream.
  */
-ostream& operator<<(ostream &o, const CPanelGroup &s)
+std::ostream& operator<<(std::ostream &o, const CPanelGroup &s)
 {
     unsigned int i;
     for (i = 0; i < s.size(); i++)
     {
-        o << "===== CPanel : " << i << " ====" << endl;
-        o << s[i] << endl;
+        o << "===== CPanel : " << i << " ====" << std::endl;
+        o << s[i] << std::endl;
     }
     for (i = 0; i < s.child.size(); i++)
     {
-        o << "===== child CPanelGroup : " << i << " ====" << endl;
-        o << s.child[i] << endl;
+        o << "===== child CPanelGroup : " << i << " ====" << std::endl;
+        o << s.child[i] << std::endl;
     }
     return o;
 }
