@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2017 Robert & Jeremy Laine
+ * Copyright (C) Robert Lainé & Jeremy Lainé
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -35,10 +35,8 @@ class CRigDef
 public:
     CRigDef();
 
-    CRigDef & operator=( const CRigDef & );
-
     /** rig ID name */
-    string rigID;
+    std::string rigID;
     /** fore triangle hoist*/
     real foreI;
     /** fore triangle base*/
@@ -84,7 +82,6 @@ public:
     real SPH[4];
     /** spreader width */
     real SPW[4];
-
 };
 
 #endif
