@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2017 Robert & Jeremy Laine
+ * Copyright (C) Robert Lainé & Jeremy Lainé
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -22,8 +22,6 @@
 
 #include "sailmould.h"
 
-using namespace std;
-
 /**************************************************************************
                              CProfile class
 ***************************************************************************
@@ -44,28 +42,6 @@ CProfile::CProfile( real rDepth, real rLeech, real rLuff)
     calcMax();
 }
 
-/**************************************************************************
-
-                               operators
-
-**************************************************************************/
-
-/** Assignment operator.
- */
-CProfile& CProfile::operator=( const CProfile &copy )
-{
-    if (&copy == this)
-        return *this;
-
-    depth = copy.depth;
-    kleech = copy.kleech;
-    kluff = copy.kluff;
-    xmax = copy.xmax;
-    zmax = copy.zmax;
-
-    return *this;
-}
-
 
 /**************************************************************************
 
@@ -74,9 +50,8 @@ CProfile& CProfile::operator=( const CProfile &copy )
 **************************************************************************/
 
 /** Compute the depth of the profile at a point located at dX along the cord
- @author Robert Laine
  */
-real CProfile::z( real dX )
+real CProfile::z( real dX ) const
 {
     /*
        dX = absiss 0 to 1 along the cord of the profile
@@ -113,9 +88,8 @@ real CProfile::z( real dX )
 }
 
 /** Compute the slope of the profile at a point located at dX along the cord
- @author Robert Laine
  */
-real CProfile::slope( real dX )
+real CProfile::slope( real dX ) const
 {
     /*
        dX = absiss 0 to 1 along the cord of the profile
@@ -152,9 +126,8 @@ real CProfile::slope( real dX )
 }
 
 /** Compute the camber of the profile at a point located at dX along the cord
- @author Robert Laine
  */
-real CProfile::camber( real dX )
+real CProfile::camber( real dX ) const
 {
     /*
        dX = absiss 0 to 1 along the cord of the profile
@@ -195,8 +168,6 @@ real CProfile::camber( real dX )
 }
 
 /** Compute the absiss x of the point of maximum depth of a profile
- *
- * @author Robert Laine
  */
 void CProfile::calcMax()
 {
@@ -268,26 +239,6 @@ CSailMould::CSailMould()
 }
 
 
-/**************************************************************************
-
-                               operators
-
-**************************************************************************/
-
-/** Assignment operator.
- */
-CSailMould & CSailMould::operator=( const CSailMould &copy )
-{
-    if (&copy == this)
-        return *this;
-
-    profile = copy.profile;
-    vertpos = copy.vertpos;
-
-    return *this;
-}
-
-
 /**************************************************************************
 
                             member functions
@@ -295,12 +246,11 @@ CSailMould & CSailMould::operator=( const CSailMould &copy )
 **************************************************************************/
 
 /** Interpolate the depth and coefficients of the profile at height h
-  @author Robert Laine
  */
 CProfile CSailMould::interpol ( const real h ) const
 {
     if ( profile.size() < 3)
-        cout << "profile < 3 !!" << endl;
+        std::cout << "profile < 3 !!" << std::endl;
 
     CProfile p;
     real pv = real(vertpos) / 100;
