@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2017 Robert & Jeremy Laine
+ * Copyright (C) Robert Lainé & Jeremy Lainé
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -23,8 +23,6 @@
 #include <geocpp/geocpp.h>
 #include <vector>
 
-using namespace std;
-
 /** Class used to work on sail profiles.
  *
  * @ingroup SailCpp
@@ -35,10 +33,9 @@ class CProfile
 public:
     CProfile( real rDepth=0.05, real rLeech=0.02, real rLuff=1 );
 
-    CProfile& operator=( const CProfile & );
-    real z( real dX );
-    real slope( real dX );
-    real camber( real dX );
+    real z( real dX ) const;
+    real slope( real dX ) const;
+    real camber( real dX ) const;
 
     /** Accessor for the depth */
     real getDepth() const
@@ -69,17 +66,20 @@ public:
     /** Set the depth */
     void setDepth( real ndepth )
     {
-        *this=CProfile( ndepth, kleech, kluff );
+        depth = ndepth;
+        calcMax();
     }
     /** Set the leech */
     void setLeech( real nkleech )
     {
-        *this=CProfile( depth, nkleech, kluff );
+        kleech = nkleech;
+        calcMax();
     }
     /** Set the luff */
     void setLuff( real nkluff )
     {
-        *this=CProfile( depth, kleech, nkluff );
+        kluff = nkluff;
+        calcMax();
     }
 
 protected:
@@ -108,12 +108,11 @@ class CSailMould
 public:
     CSailMould();
 
-    CSailMould & operator=( const CSailMould & );
     CProfile interpol( const real h ) const;
 
     /** the mould's profiles ( top, middle, bottom ) */
     //  CProfile profile[3];
-    vector<CProfile> profile;
+    std::vector<CProfile> profile;
 
     /** vertical position of profile[1] in percent */
     int vertpos;
