@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2017 Robert & Jeremy Laine
+ * Copyright (C) Robert Lainé & Jeremy Lainé
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -28,7 +28,7 @@ CSailDispLabel::CSailDispLabel( QWidget * parent )
 {
     // set the background to white
     QPalette pal = palette();
-    pal.setColor( QPalette::Background, Qt::white );
+    pal.setColor( QPalette::Window, Qt::white );
     setPalette( pal );
 }
 
@@ -72,6 +72,7 @@ void CSailDispLabel::paintEvent( QPaintEvent * )
     // set coordinate system to match the logical viewport
     painter.setWindow(logicalRect());
     painter.setFontSize(8, zoom());
+    painter.setPenColor(Qt::black);
     painter.setPenWidth();
 
     // draw the sail
@@ -104,9 +105,10 @@ void CSailDispLabel::resizeEvent( QResizeEvent * )
  */
 void CSailDispLabel::wheelEvent( QWheelEvent *event)
 {
-    if (event->delta()>0)
+    const int delta = event->pixelDelta().y();
+    if (delta > 0)
         zoomIn();
-    else
+    else if (delta < 0)
         zoomOut();
     redraw();
 }
