@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2017 Robert & Jeremy Laine
+ * Copyright (C) Robert Lainé & Jeremy Lainé
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -179,7 +179,7 @@ void CSailDoc::get
  * @param name the name of the string
  */
 void CSailDoc::get
-( const QDomNode &parent, string &s, const QString &name )
+( const QDomNode &parent, std::string &s, const QString &name )
 {
     QDomElement e = findElement( parent, "string", name);
     QDomNamedNodeMap attr = e.attributes();
@@ -246,7 +246,7 @@ void CSailDoc::get
     }
     else
     {
-        throw invalid_argument("CSailDoc::get : unknown panel group type");
+        throw std::invalid_argument("CSailDoc::get : unknown panel group type");
     }
 }
 
@@ -452,7 +452,7 @@ void CSailDoc::get
         get(e, d.footHemW, "footHemW");
 
     }
-    catch (doc_element_error e)
+    catch (doc_element_error const&)
     {
         /** catch read error to avoid killing the program */
     }
@@ -524,7 +524,7 @@ void CSailDoc::get
     {
         get(e, g.type, "type");
     }
-    catch (doc_element_error e)
+    catch (doc_element_error const&)
     {
         // to avoid killing the program
     }
@@ -613,7 +613,7 @@ void CSailDoc::get
         get(e, p.mainWindowHeight, "mainWindowHeight");
         get(e, p.mainWindowWidth, "mainWindowWidth");
     }
-    catch (doc_element_error e)
+    catch (doc_element_error const&)
     {
         // we do not let this kill the program
     }
@@ -700,7 +700,7 @@ void CSailDoc::put(QDomNode &parent, const real &r, const QString &name )
 
 /** Puts a std::string value to an XML document.
  */
-void CSailDoc::put(QDomNode &parent, const string &s, const QString &name )
+void CSailDoc::put(QDomNode &parent, const std::string &s, const QString &name )
 {
     QDomElement e = createElement("string", name, QString::fromStdString(s));
     parent.appendChild(e);
