@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2017 Robert & Jeremy Laine
+ * Copyright (C) Robert Lainé & Jeremy Lainé
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -39,7 +39,7 @@ private slots:
 
 public:
     /** the widgets of each view */
-    vector<CSailViewerPanel *> panel;
+    std::vector<CSailViewerPanel*> panel;
 };
 
 #endif
