@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2017 Robert & Jeremy Laine
+ * Copyright (C) Robert Lainé & Jeremy Lainé
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -39,11 +39,11 @@ public:
     ;
 
     void write(const CPanelGroup &sail, const QString &filename) const;
-    void writePanel(ofstream &out, const CPanel &panel) const;
-    void writePanelHeader(ofstream &out, const CPanel &panel) const;
-    void writeDraw(ofstream &out, unsigned int ct) const;
-    void writeCut(ofstream &out, unsigned int ct) const;
-    void writePoint(ofstream &out, CPoint3d p0) const;
+    void writePanel(std::ofstream &out, const CPanel &panel) const;
+    void writePanelHeader(std::ofstream &out, const CPanel &panel) const;
+    void writeDraw(std::ofstream &out, unsigned int ct) const;
+    void writeCut(std::ofstream &out, unsigned int ct) const;
+    void writePoint(std::ofstream &out, CPoint3d p0) const;
 
 };
 
