@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2017 Robert & Jeremy Laine
+ * Copyright (C) Robert Lainé & Jeremy Lainé
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -29,11 +29,11 @@
  */
 void CSailTxtWriter::write(const CPanelGroup &sail, const QString &filename) const
 {
-    ofstream myOut;
-    myOut.open(QFile::encodeName(filename), ios::out);
+    std::ofstream myOut;
+    myOut.open(QFile::encodeName(filename), std::ios::out);
     if (!myOut.is_open())
         throw write_error("CSailTxtWriter::write : unable to write to specified file");
-    myOut << sail.title << endl;
+    myOut << sail.title << std::endl;
     myOut << sail;
     myOut.close();
 }
