@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2017 Robert & Jeremy Laine
+ * Copyright (C) Robert Lainé & Jeremy Lainé
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -47,7 +47,7 @@ CLabelProfile::CLabelProfile( QWidget *parent, CProfile *ptr)
 {
     // set the background to white
     QPalette pal = palette();
-    pal.setColor( QPalette::Background, Qt::white );
+    pal.setColor( QPalette::Window, Qt::white );
     setPalette( pal );
     setMinimumSize( QSize( 300, 100 ) );
 }
@@ -58,6 +58,11 @@ CLabelProfile::CLabelProfile( QWidget *parent, CProfile *ptr)
 void CLabelProfile::paintEvent( QPaintEvent *)
 {
     QPainter painter( this );
+    QPen pen = painter.pen();
+    pen.setColor(Qt::black);
+    pen.setWidth(0);
+    painter.setPen(pen);
+
     QRect vRect = painter.viewport();
     painter.eraseRect(vRect);
 
@@ -148,7 +153,7 @@ CWidgetProfile::CWidgetProfile( QWidget *parent, CProfile *ptr,
 
     spinLuff = new QSpinBox( grpProfile );
     spinLuff->setMaximum( 18 );
-    spinLuff->setMinimum( 1 );
+    spinLuff->setMinimum( 0 );
     spinLuff->setValue( 1 );
     spinBoxesLayout->addWidget( spinLuff );
     QSpacerItem* spacer = new QSpacerItem( 20, 20, QSizePolicy::MinimumExpanding, QSizePolicy::Minimum );
@@ -160,7 +165,7 @@ CWidgetProfile::CWidgetProfile( QWidget *parent, CProfile *ptr,
     spinBoxesLayout->addWidget( lblDepth );
 
     spinDepth = new QSpinBox( grpProfile );
-    spinDepth->setMaximum( 22 );
+    spinDepth->setMaximum( 40 );
     spinDepth->setMinimum( 1 );
     spinDepth->setValue( 10 );
     spinBoxesLayout->addWidget( spinDepth );
