@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2017 Robert & Jeremy Laine
+ * Copyright (C) Robert Lainé & Jeremy Lainé
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -42,7 +42,7 @@ CLabelProfileVert::CLabelProfileVert( QWidget *parent, CSailMould *ptr)
 {
     // set the background to white
     QPalette pal = palette();
-    pal.setColor( QPalette::Background, Qt::white );
+    pal.setColor( QPalette::Window, Qt::white );
     setPalette( pal );
 
     setMinimumSize( QSize( 120, 400 ) );
@@ -54,6 +54,10 @@ CLabelProfileVert::CLabelProfileVert( QWidget *parent, CSailMould *ptr)
 void CLabelProfileVert::paintEvent( QPaintEvent *)
 {
     QPainter painter( this );
+    QPen pen = painter.pen();
+    pen.setColor(Qt::black);
+    pen.setWidth(0);
+    painter.setPen(pen);
 
     QRect vRect = painter.viewport();
     painter.eraseRect(vRect);
